@@ -14,8 +14,9 @@
 # Author(s):
 #             Gunnar Wrobel <wrobel@gentoo.org>
 #
+'''Defines the configuration options and provides parsing functionality.'''
 
-__version__ = "$Id: config.py 218 2006-07-25 12:31:27Z wrobel $"
+__version__ = "$Id: config.py 240 2006-09-06 07:45:11Z wrobel $"
 
 #===============================================================================
 #
@@ -23,7 +24,7 @@ __version__ = "$Id: config.py 218 2006-07-25 12:31:27Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import os, sys, optparse, ConfigParser
+import sys, ConfigParser
 
 from   optparse                 import OptionParser, OptionGroup
 from   layman.debug             import OUT
@@ -36,11 +37,22 @@ from   layman.version           import VERSION
 #-------------------------------------------------------------------------------
 
 class Config(object):
+    '''Handles the configuration.'''
 
     def __init__(self):
         '''
         Creates and describes all possible polymeraZe options and creates
         a debugging object.
+
+        >>> import os.path
+        >>> here = os.path.dirname(os.path.realpath(__file__))
+        >>> sys.argv.append('--config')
+        >>> sys.argv.append(here + '/../etc/layman.cfg')
+        >>> a = Config()
+        >>> a['overlays']
+        '\\nhttp://www.gentoo.org/proj/en/overlays/layman-global.txt'
+        >>> sorted(a.keys())
+        ['cache', 'config', 'config_dir', 'local_list', 'make_conf', 'nocheck', 'overlays', 'proxy', 'storage']
         '''
 
         self.defaults = {'config_dir': '/etc/layman',
@@ -49,17 +61,20 @@ class Config(object):
                          'cache'     : '%(storage)s/cache',
                          'local_list': '%(storage)s/overlays.xml',
                          'make_conf' : '%(storage)s/make.conf',
+                         'nocheck'   : 'no',
                          'proxy'     : '',
-                         'overlays'  : 
-                         'http://www.gentoo.org/proj/en/overlays/layman-global.txt',}
+                         'overlays'  :
+                         'http://www.gentoo.org/proj/en/overlays/layman-global.'
+                         'txt',}
 
 
         self.parser = OptionParser(
-            usage   = '\n\nlayman -a/-d/-S|overlay\nlayman -f [-o url]\nlayman -l|-L',
+            usage   = '\n\nlayman -a/-d/-S|overlay\nlayman -f [-o url]\nlayman' \
+            ' -l|-L',
             version = VERSION)
 
         #-----------------------------------------------------------------
-        # Main Options 
+        # Main Options
 
         group = OptionGroup(self.parser,
                             '<Actions>')
@@ -113,7 +128,7 @@ class Config(object):
         self.parser.add_option_group(group)
 
         #-----------------------------------------------------------------
-        # Additional Options 
+        # Additional Options
 
         group = OptionGroup(self.parser,
                             '<Path options>')
@@ -133,7 +148,7 @@ class Config(object):
         self.parser.add_option_group(group)
 
         #-----------------------------------------------------------------
-        # Output Options 
+        # Output Options
 
         group = OptionGroup(self.parser,
                             '<Output options>')
@@ -143,6 +158,13 @@ class Config(object):
                          action = 'store_true',
                          help = 'Increase amount of output.')
 
+        group.add_option('-k',
+                         '--nocheck',
+                         action = 'store_true',
+                         help = 'Do not check overlay definitions and do not i'
+                         'ssue a warning if description or contact information'
+                         ' are missing.')
+
         #-----------------------------------------------------------------
         # Debug Options
 
@@ -153,7 +175,7 @@ class Config(object):
         (self.options, args) = self.parser.parse_args()
 
         # handle debugging
-	OUT.cli_handle(self.options)
+        OUT.cli_handle(self.options)
 
         # Fetch only an alternate config setting from the options
         if not self.options.__dict__['config'] is None:
@@ -190,6 +212,11 @@ class Config(object):
         OUT.debug('Retrieving option', 8)
 
         if self.config.has_option('MAIN', key):
+            if key == 'nocheck':
+                if self.config.get('MAIN', key).lower() == 'yes':
+                    return True
+                else:
+                    return False
             return self.config.get('MAIN', key)
 
         OUT.debug('Retrieving option', 8)
@@ -202,24 +229,34 @@ class Config(object):
         return None
 
     def keys(self):
+        '''Special handler for the configuration keys.'''
 
         OUT.debug('Retrieving keys', 8)
-        
+
         keys = [i for i in self.options.__dict__.keys()
                 if not self.options.__dict__[i] is None]
-        
+
         OUT.debug('Retrieving keys', 8)
-        
+
         keys += [name for name, value in self.config.items('MAIN')
                  if not name in keys]
 
         OUT.debug('Retrieving keys', 8)
-        
+
         keys += [i for i in self.defaults.keys()
                  if not i in keys]
 
         OUT.debug('Retrieving keys', 8)
-        
+
         return keys
 
 
+#===============================================================================
+#
+# Testing
+#
+#-------------------------------------------------------------------------------
+
+if __name__ == '__main__':
+    import doctest
+    doctest.testmod(sys.modules[__name__])
