@@ -14,8 +14,9 @@
 # Author(s):
 #             Gunnar Wrobel <wrobel@gentoo.org>
 #
+''' Tar overlay support.'''
 
-__version__ = "$Id: tar.py 168 2006-06-26 22:37:29Z wrobel $"
+__version__ = "$Id: tar.py 236 2006-09-05 20:39:37Z wrobel $"
 
 #===============================================================================
 #
@@ -26,7 +27,6 @@ __version__ = "$Id: tar.py 168 2006-06-26 22:37:29Z wrobel $"
 import os, os.path, sys, urllib, shutil
 
 from   layman.utils             import path
-from   layman.debug             import OUT
 from   layman.overlays.overlay  import Overlay
 
 #===============================================================================
@@ -41,13 +41,14 @@ class TarOverlay(Overlay):
     A dummy tar handler that overwrites the __init__ method
     so that we don't need to provide xml input:
 
+    >>> from   layman.debug             import OUT
     >>> class DummyTar(TarOverlay):
     ...   def __init__(self):
     ...     self.name = 'dummy'
     ...     here = os.path.dirname(os.path.realpath(__file__))
     ...     self.src  = here + '/../tests/testfiles/layman-test.tar.bz2'
     ...     self.subpath = 'layman-test'
-
+    ...     self.format = 'bz2'
     >>> testdir = os.tmpnam()
     >>> os.mkdir(testdir)
     >>> a = DummyTar()
@@ -60,18 +61,23 @@ class TarOverlay(Overlay):
     '''
 
     type = 'Tar'
-    
-    binary = '/bin/tar' 
 
-    def __init__(self, xml):
-        
-        Overlay.__init__(self, xml)
+    binary = '/bin/tar'
+
+    def __init__(self, xml, ignore = False):
+
+        Overlay.__init__(self, xml, ignore)
+
+        if '&format' in self.data.keys():
+            self.format = self.data['&format']
+        else:
+            self.format = ''
 
         if '&subpath' in self.data.keys():
             self.subpath = self.data['&subpath']
         else:
             self.subpath = ''
-        
+
         if '&category' in self.data.keys():
             if self.subpath:
                 raise Exception('Cannot use "category" and "subpath" at the same'
@@ -80,31 +86,34 @@ class TarOverlay(Overlay):
             self.category = self.data['&category']
         else:
             self.category = ''
-        
+
     def add(self, base):
+        '''Add overlay.'''
 
         self.supported()
 
-        dir = path([base, self.name])
+        mdir = path([base, self.name])
 
-        if os.path.exists(dir):
-            raise Exception('Directory ' + dir + ' already exists. Will not ove'
-                            'rwrite its contents!')
+        if os.path.exists(mdir):
+            raise Exception('Directory ' + mdir + ' already exists. Will not ov'
+                            'erwrite its contents!')
 
-        if self.src[-3:] == 'bz2':
+        if self.format == 'bz2' or (not self.format and self.src[-3:] == 'bz2'):
             ext = 'bz2'
             opt = '-j'
-        elif self.src[-2:] == 'gz':
+        elif self.format == 'gz' or (not self.format and self.src[-2:] == 'gz'):
             ext = 'gz'
             opt = '-z'
+        else:
+            raise Exception('Unsupported file format!')
 
         try:
 
             tar = urllib.urlopen(self.src).read()
 
-        except Exception, e:
-            raise Exception('Failed to fetch the tar package from: ' 
-                            + self.src + '\nError was:' + str(e))
+        except Exception, error:
+            raise Exception('Failed to fetch the tar package from: '
+                            + self.src + '\nError was:' + str(error))
 
         pkg = path([base, self.name + '.tar.' + ext])
 
@@ -114,45 +123,47 @@ class TarOverlay(Overlay):
             out_file.write(tar)
             out_file.close()
 
-        except Exception, e:
-            raise Exception('Failed to store tar package in ' 
-                            + pkg + '\nError was:' + str(e))
+        except Exception, error:
+            raise Exception('Failed to store tar package in '
+                            + pkg + '\nError was:' + str(error))
 
         if self.subpath:
             target = path([base, 'tmp'])
         else:
             if self.category:
-                target = dir + '/' + self.category
+                target = mdir + '/' + self.category
             else:
-                target = dir
+                target = mdir
 
         os.makedirs(target)
 
-        result = self.cmd(self.binary + ' -v -x ' + opt + ' -f ' + pkg + ' -C ' 
-                          + target)
+        result = self.cmd(self.binary + ' -v -x ' + opt + ' -f "' + pkg
+                          + '" -C "' + target + '"')
 
         if self.subpath:
             source = target + '/' + self.subpath
             if os.path.exists(source):
                 try:
-                    os.rename(source, dir)
-                except Exception, e:
-                    raise Exception('Failed to rename tar subdirectory ' + source 
-                                    + ' to ' + dir + '\nError was:' + str(e))
+                    os.rename(source, mdir)
+                except Exception, error:
+                    raise Exception('Failed to rename tar subdirectory ' +
+                                    source + ' to ' + mdir + '\nError was:'
+                                    + str(error))
             else:
                 raise Exception('Given subpath "' + source + '" does not exist '
                                 ' in the tar package!')
             try:
                 shutil.rmtree(target)
-            except Exception, e:
+            except Exception, error:
                 raise Exception('Failed to remove unnecessary tar structure "'
-                                + target + '"\nError was:' + str(e))
+                                + target + '"\nError was:' + str(error))
 
         os.unlink(pkg)
 
         return result
 
     def sync(self, base):
+        '''Sync overlay.'''
 
         self.supported()
 
@@ -161,11 +172,12 @@ class TarOverlay(Overlay):
         self.add(base)
 
     def supported(self):
-        
-        return Overlay.supported(self, [(self.binary,  'tar', 'app-arch/tar'),])
+        '''Overlay type supported?'''
+
+        return Overlay.supported(self, [(self.binary,  'tar', 'app-arch/tar'), ])
 
 if __name__ == '__main__':
-    import doctest, sys
+    import doctest
 
     # Ignore warnings here. We are just testing
     from warnings     import filterwarnings, resetwarnings
