@@ -17,7 +17,7 @@
 
 '''Utility functions to deal with xml nodes. '''
 
-__version__ = '$Id: utils.py 200 2006-07-17 10:12:41Z wrobel $'
+__version__ = '$Id: utils.py 236 2006-09-05 20:39:37Z wrobel $'
 
 #===============================================================================
 #
@@ -25,9 +25,7 @@ __version__ = '$Id: utils.py 200 2006-07-17 10:12:41Z wrobel $'
 #
 #-------------------------------------------------------------------------------
 
-import xml.dom.minidom, types, re
-
-from   layman.debug           import OUT
+import types, re
 
 #===============================================================================
 #
@@ -36,10 +34,11 @@ from   layman.debug           import OUT
 #-------------------------------------------------------------------------------
 
 def node_to_text(node):
-    ''' 
+    '''
     Reduces an xml node to its text elements. The function does not
-    collect the text nodes recursively.  
+    collect the text nodes recursively.
 
+    >>> import xml.dom.minidom
     >>> imp = xml.dom.minidom.getDOMImplementation()
     >>> doc = imp.createDocument('test', 'root', None)
     >>> root =  doc.childNodes[0]
@@ -56,7 +55,7 @@ def node_to_text(node):
 
     >>> node_to_text(root)
     'texttext'
-    
+
     '''
     text = ''
 
@@ -74,6 +73,7 @@ def node_to_dict(node):
     elements will be collapsed and stored in a n entry prepended with
     '@'. Comments will be ignored.
 
+    >>> import xml.dom.minidom
     >>> imp = xml.dom.minidom.getDOMImplementation()
     >>> doc = imp.createDocument('test', 'root', None)
     >>> root =  doc.childNodes[0]
@@ -97,7 +97,7 @@ def node_to_dict(node):
 
     >>> node_to_dict(root)
     {'<text>1': {'@': 'text', '&&attr': 'test'}, '<text>2': {'@': ''}, '@': 'texttext'}
-    
+
     '''
     result = {}
 
@@ -115,7 +115,7 @@ def node_to_dict(node):
         if child.nodeType == child.ELEMENT_NODE:
             index = 1
             while ('<' + child.tagName + '>' + str(index)) in result.keys():
-                index+=1
+                index += 1
             result['<' + child.tagName + '>' + str(index)] = node_to_dict(child)
 
     result['@'] = text
@@ -125,6 +125,7 @@ def node_to_dict(node):
 def dict_to_node(data, document, root_name):
     ''' Reverts the node_to_dict operation.
 
+    >>> import xml.dom.minidom
     >>> imp = xml.dom.minidom.getDOMImplementation()
     >>> doc = imp.createDocument('test', 'root', None)
     >>> a = {'<text>1': {'@': 'text', '&&attr': 'test'}, '<text>2': {'@': ''}, '@': 'texttext'}
@@ -196,6 +197,12 @@ def path(path_elements):
 
     return pathname
 
+#===============================================================================
+#
+# Testing
+#
+#-------------------------------------------------------------------------------
+
 if __name__ == '__main__':
     import doctest, sys
     doctest.testmod(sys.modules[__name__])
